@@ -17,6 +17,9 @@ class LoginView(SubjectOnboardingMixin):
     form_class = PolymorphicPrincipalForm
     allow_signup = True
 
+    class form_class(PolymorphicPrincipalForm):
+        allow_create = False
+
     # TODO: Implement a mechanism to keep the below methods in sync.
     def must_redirect(self):
         """Return a boolean indicating if we must redirect an authenticated user
@@ -77,7 +80,6 @@ class LoginView(SubjectOnboardingMixin):
             form = ChoosePasswordForm
             self.must_login = False
 
-        form.allow_create = self.allow_signup
         return form
 
     def get_template_names(self):
